==> v8.3.zip: ru_twords_ru_tw/bible/other/captive.md <==
# плен, пленник

## Определение:

Пленом называется насильственный захват людей и ограничение их свободы, например, принудительное содержание их в другой стране.

* Жители Иудеи были уведены в Вавилон. Их плен продлился семьдесят лет.
* Очень часто захватчики принуждают пленников тяжело трудиться.
* Даниил и Неемия были израильскими пленниками, трудившимися на благо вавилонских царей.
* Выражение “взять в плен” означает “захватить кого-либо с применением силы”.
* “Держать в плену” — значит “не давать свободы”, “насильно удерживать”.
* Апостол Павел наставлял верующих “брать в плен” каждую мысль и подчинять её Христу. В противном случае человек может попасть в “плен греха”, то есть грех может начать его контролировать.

## Варианты перевода

* В зависимости от контекста выражение “держать в плену” можно перевести как “не давать свободы”, “не выпускать из заточения”, “принуждать жить в чужой земле”.
* Выражение “увести в плен” можно перевести как “захватить”, “лишить свободы”, “заставить жить на чужбине”.
* Слово “пленник” можно заменить словами “человек, попавший в плен”, “порабощённый человек”.
* В зависимости от контекста слово “плен” можно перевести как “неволя”, “несвобода”, “рабство”, “принудительное содержание”.

(См. также: [Вавилон](../names/babylon.md), [плен](../other/exile.md), [тюрьма](../other/prison.md), [схватить](../other/seize.md))

## Ссылки на библейский текст:

* [2 Кор. 10:5-6](rc://*/tn/help/2co/10/05)
* [Ис. 20:3-4](rc://*/tn/help/isa/20/03)
* [Иер. 43:1-3](rc://*/tn/help/jer/43/01)
* [Лк. 4:18-19](rc://*/tn/help/luk/04/18)

## Данные о слове:

* Номера Стронга: H1123, H1473, H1540, H1546, H1547, H2925, H6808, H7617, H7622, H7628, H7633, H7686, H7870, G161, G162, G163, G164, G2221

==> v9.2.zip: ru_twords_ru_tw/bible/other/captive.md <==
# плен, пленник
## Определение:

Пленом называется насильственный захват людей и ограничение их свободы, например, принудительное содержание их в другой стране.

* Жители Иудеи были уведены в Вавилон. Их плен продлился семьдесят лет. 
* Очень часто захватчики принуждают пленников тяжело трудиться.   
* Даниил и Неемия были израильскими пленниками, трудившимися на благо вавилонских царей. 
* Выражение “взять в плен” означает “захватить кого-либо с применением силы”. 
* “Держать в плену” — значит “не давать свободы”, “насильно удерживать”.  
* Апостол Павел наставлял верующих “брать в плен” каждую мысль и подчинять её Христу. В противном случае человек может попасть в “плен греха”, то есть грех может начать его контролировать. 

## Варианты перевода

* В зависимости от контекста выражение “держать в плену” можно перевести как “не давать свободы”, “не выпускать из заточения”, “принуждать жить в чужой земле”. 
* Выражение “увести в плен” можно перевести как “захватить”, “лишить свободы”, “заставить жить на чужбине”. 
* Слово “пленник” можно заменить словами “человек, попавший в плен”, “порабощённый человек”. 
* В зависимости от контекста слово “плен” можно перевести как “неволя”, “несвобода”, “рабство”, “принудительное содержание”. 

(См. также: [Вавилон](../names/babylon.md), [плен](../other/exile.md), [тюрьма](../other/prison.md), [схватить](../other/seize.md))

## Ссылки на библейский текст:

* [2 Кор. 10:5-6](rc://ru/tn/help/2co/10/05)
* [Ис. 20:3-4](rc://ru/tn/help/isa/20/03)
* [Иер. 43:1-3](rc://ru/tn/help/jer/43/01)
* [Лк. 4:18-19](rc://ru/tn/help/luk/04/18)

## Данные о слове:

* Номера Стронга: H1123, H1473, H1540, H1546, H1547, H2925, H6808, H7617, H7622, H7628, H7633, H7686, H7870, G161, G162, G163, G164, G2221
